@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 """
 pyweblib - several modules for web programming tasks
-(C) 2001 by Michael Stroeder <michael@stroeder.com>
+(C) 1998-2015 by Michael Ströder <michael@stroeder.com>
 
 This module including sub-modules is distributed under the terms
 of the GPL (GNU GENERAL PUBLIC LICENSE) Version 2
@@ -15,8 +16,14 @@ pyweblib.session           server-side web session handling
 pyweblib.helper            misc. stuff useful in CGI-BINs
 pyweblib.sslenv            retrieves SSL-related env vars
 pyweblib.httphelper        very basic HTTP functions
-
-$Id: __init__.py,v 1.35 2014/03/22 18:37:34 michael Exp $
 """
 
-__version__ = '1.3.11'
+# For the whole module-package
+__version__ = '1.3.12'
+__author__ = u'Michael Ströder'
+__copyright__ = u'(C) 1998-2015 by Michael Ströder <michael@stroeder.com>'
+__license__ = 'GPL (GNU GENERAL PUBLIC LICENSE) Version 2'
+
+# File specific
+__revision__ = '$Revision: 1.39 $'.split(' ')[1]
+__info__ = '$Id: __init__.py,v 1.39 2015/01/10 16:37:13 michael Exp $'
